@@ -3,11 +3,23 @@ from django.contrib import admin
 from mptt.admin import MPTTModelAdmin
 import reversion
 
-from .models import Page, Carousel, CarouselImage, Attachment
+from .models import Page, Carousel, CarouselImage, Attachment, Nav, NavItem
 
 
 class SiteEntityAdmin(reversion.VersionAdmin, admin.ModelAdmin):
     prepopulated_fields = {"slug": ("title",)}
+    list_editable = ['order', 'status']
+    list_display = ['title', 'slug', 'status', 'order']
+    list_filter = ['status']
+    search_fields = ['title']
+
+    class Media:
+        js = (
+            'js/jquery.min.js',
+            'js/jquery-ui.min.js',
+            'admin/js/list-reorder.js',
+            'admin/js/inline-reorder.js',
+        )
 
 
 class DisplayableAdmin(SiteEntityAdmin):
@@ -26,8 +38,17 @@ class AttachmentAdmin(SiteEntityAdmin):
 admin.site.register(Attachment, AttachmentAdmin)
 
 
-class AttachmentInline(admin.TabularInline):
-    model = Attachment
+class NavItemInline(admin.TabularInline):
+    model = NavItem
+    extra = 0
+
+
+class NavAdmin(SiteEntityAdmin):
+    inlines = [
+        NavItemInline
+    ]
+
+admin.site.register(Nav, NavAdmin)
 
 
 class CarouselImageInline(admin.TabularInline):
