@@ -24,12 +24,27 @@ class SiteEntity(models.Model):
     )
 
     title = models.CharField(max_length=255)
+    identifier = models.CharField(max_length=255, null=True, blank=True)
     slug = models.SlugField(max_length=255)
     order = models.IntegerField(null=True, blank=True)
     status = StatusField()
 
     objects = PassThroughManager.for_queryset_class(SiteEntityQuerySet)()
 
+    def save(self, *args, **kwargs):
+        model = self.__class__
+
+        if self.order is None:
+            # Append
+            try:
+                last = model.objects.order_by('-order')[0]
+                self.order = last.order + 1
+            except IndexError:
+                # First row
+                self.order = 0
+
+        return super(SiteEntity, self).save(*args, **kwargs)
+
     def __str__(self):
         return self.title
 
@@ -37,7 +52,7 @@ class SiteEntity(models.Model):
         return self.title
 
     class Meta:
-        ordering = ['order', 'title']
+        ordering = ['order']
 
 
 class Displayable(SiteEntity):
@@ -82,22 +97,34 @@ class Page(MPTTModel, Displayable):
         ordering = ['order']
 
 
-class Carousel(models.Model):
-    name = models.CharField(max_length=45, unique=True)
-    images = models.ManyToManyField(Attachment, related_name='carousels',
-        through='CarouselImage')
-
-    def __str__(self):
-        return self.name
-
-    def __unicode__(self):
-        return self.name
+class Carousel(SiteEntity):
+    pass
 
 
 class CarouselImage(models.Model):
-    image = models.ForeignKey(Attachment)
     carousel = models.ForeignKey(Carousel)
-    order = models.IntegerField()
+    image = ImageField(upload_to='carousel_img')
+    description = models.TextField(blank=True)
+    order = models.IntegerField(default=0)
+
+
+class Nav(SiteEntity):
+    items = models.ManyToManyField(Page, related_name='navs',
+        through='NavItem')
+
+
+class NavItem(models.Model):
+    page = models.ForeignKey(Page, related_name='navitems')
+    nav = models.ForeignKey(Nav, related_name='navitems')
+    show_children = models.BooleanField(default=True)
+    order = models.IntegerField(default=0)
+
+    @property
+    def show_id(self):
+        return self.pk
+
+    def __unicode__(self):
+        return unicode(self.page)
 
     class Meta:
         ordering = ['order']
